@@ -3,6 +3,6 @@ PyIter is a Python package for iterative operations inspired by the Kotlin、CSh
 TypeSrcipt and Rust . Enables strong typing and type inference for iterative operations.
 """
 
-from .sequence import Sequence, seq, it
+from .sequence import Sequence, sequence, seq, iterate, it
 
-__ALL__ = ['Sequence', 'seq', 'it']
+__ALL__ = [Sequence, sequence, seq, iterate, it]
