@@ -1359,7 +1359,8 @@ class Sequence(Generic[T], Iterable[T]):
     def zip(self, other: Iterable[R], transform: Callable[[T, R], V] = lambda a, b:(a, b)) -> Sequence[V]:
         return MergingSequence(self, other, transform)
     
-    def zip_with_next(self, transform: Callable[[T, T], V]) -> Sequence[V]:
+    @overload
+    def zip_with_next(self) -> Sequence[Tuple[T, T]]:
         """
          Returns a sequence containing the results of applying the given [transform] function
         to an each pair of two adjacent elements in this sequence.
@@ -1368,8 +1369,32 @@ class Sequence(Generic[T], Iterable[T]):
         >>> lst = ['a', 'b', 'c']
         >>> it(lst).zip_with_next(lambda x, y: x + '__' + y)
         ['a__b', 'b__c']
+
+         Example 2:
+        >>> lst = ['a', 'b', 'c']
+        >>> it(lst).zip_with_next()
+        [('a', 'b'), ('b', 'c')]
         """
-        return MergingWithNextSequence(self, transform)
+        ...
+    @overload
+    def zip_with_next(self, transform: Callable[[T, T], V]) -> Sequence[V]:
+        ...
+    def zip_with_next(self, transform: Optional[Callable[[T, T], V]]=None) -> Tuple[Sequence[V], Sequence[Tuple[T, T]]]:
+        """
+         Returns a sequence containing the results of applying the given [transform] function
+        to an each pair of two adjacent elements in this sequence.
+        
+         Example 1:
+        >>> lst = ['a', 'b', 'c']
+        >>> it(lst).zip_with_next(lambda x, y: x + '__' + y)
+        ['a__b', 'b__c']
+
+         Example 2:
+        >>> lst = ['a', 'b', 'c']
+        >>> it(lst).zip_with_next()
+        [('a', 'b'), ('b', 'c')]
+        """
+        return MergingWithNextSequence(self, transform or (lambda a, b: (a, b)))
     
     def with_index(self):
         """
@@ -1970,8 +1995,12 @@ def sequence(*iterable: Iterable[T]) -> Sequence[T]:
      Example 3:
     >>> sequence(range(10)).map(lambda x: x*x)
     [0, 1, 4, 9, 16, 25, 36, 49, 64, 81]
+
+     Example 4:
+    >>> sequence('abc').len
+    1
     """
-    if len(iterable) == 1 and isinstance(iterable[0], Iterable):
+    if len(iterable) == 1 and isinstance(iterable[0], Iterable) and not isinstance(iterable[0], str):
         return Sequence(iterable[0])
     return Sequence(iterable)
 
